4Suite API Documentation: Ft.Xml.Xslt.GenericVariable

4Suite™ API Documentation

# ► Module Ft.Xml.Xslt.GenericVariable

Base implementation of XSLT variable assigning elements

    Copyright 2002 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Classes: GenericVariableElement, PopVariablesNode, PushVariablesNode |  |  |  | Globals: EMPTY_NAMESPACE, FT_EXT_NAMESPACE, XSL_NAMESPACE

## Classes

class GenericVariableElement(Ft.Xml.Xslt.StylesheetTree.XsltElement)

  ### Methods

  instantiate(self, context, processor)
    Overrides: instantiate from class XsltElement
  setup(self)
    Overrides: setup from class XsltElement

  ### Methods inherited from class Ft.Xml.Xslt.StylesheetTree.XsltElement

  __init__, __str__, appendChild, expandQName, insertChild, parseAVT, parseExpression, parsePattern, processChildren, splitQName

  ### Methods inherited from class Ft.Xml.Xslt.StylesheetTree.XsltNode

  idle, isLastChild, isPseudoNode, pprint, prime

  ### Members

  category = None
  content = <Ft.Xml.Xslt.ContentInfo.Rep instance>
  doesSetup = True
  legalAttrs = {'f:node-set': <Ft.Xml.Xslt.AttributeInfo.YesNoAvt instance>, 'name': <Ft.Xml.Xslt.AttributeInfo.QName instance>, 'select': <Ft.Xml.Xslt.AttributeInfo.Expression instance>}

  ### Members inherited from class Ft.Xml.Xslt.StylesheetTree.XsltElement

  validator

  ### Members inherited from class Ft.Xml.Xslt.StylesheetTree.XsltNode

  attributes, baseUri, children, columnNumber, doesIdle, doesPrime, expandedName, importIndex, lineNumber, nodeName, parent, root
class PopVariablesNode(Ft.Xml.Xslt.StylesheetTree.XsltNode)

  ### Methods

  __init__(self, savedVariables)
  instantiate(self, context, processor)
    Overrides: instantiate from class XsltNode
  isPseudoNode(self)
    Overrides: isPseudoNode from class XsltNode

  ### Methods inherited from class Ft.Xml.Xslt.StylesheetTree.XsltNode

  idle, isLastChild, pprint, prime, setup

  ### Members inherited from class Ft.Xml.Xslt.StylesheetTree.XsltNode

  attributes, baseUri, children, columnNumber, doesIdle, doesPrime, doesSetup, expandedName, importIndex, lineNumber, nodeName, parent, root
class PushVariablesNode(Ft.Xml.Xslt.StylesheetTree.XsltNode)
  # pseudo-nodes for save/restore of variable bindings

  ### Methods

  __init__(self, root, baseUri)
  instantiate(self, context, processor)
    Overrides: instantiate from class XsltNode
  isPseudoNode(self)
    Overrides: isPseudoNode from class XsltNode
  prime(self, processor, context)
    Overrides: prime from class XsltNode

  ### Methods inherited from class Ft.Xml.Xslt.StylesheetTree.XsltNode

  idle, isLastChild, pprint, setup

  ### Members inherited from class Ft.Xml.Xslt.StylesheetTree.XsltNode

  attributes, baseUri, children, columnNumber, doesIdle, doesPrime, doesSetup, expandedName, importIndex, lineNumber, nodeName, parent, root

## Globals

EMPTY_NAMESPACE = None
FT_EXT_NAMESPACE = 'http://xmlns.4suite.org/ext'
XSL_NAMESPACE = u'http://www.w3.org/1999/XSL/Transform'